==> sessiond-0.2.tar.gz: sessiond-0.2/sessiond.cpp <==
// sessiond - SSL session cache daemon, file sessiond.cpp
// Copyright (C) 2009 Michal Trojnara <Michal.Trojnara@mirt.net>
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2 of the License, or (at your
// option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, see <http://www.gnu.org/licenses>.
//
// Linking sessiond statically or dynamically with other modules is making
// a combined work based on sessiond. Thus, the terms and conditions of
// the GNU General Public License cover the whole combination.

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/socket.h>
#include <netinet/in.h>

void process_request(const int); // defined in comm.cpp

int main(int argc, char *argv[]) {
    u_short port;
    if(argc<2)
        port=54321;
    else
        port=atoi(argv[1]);
    if(!port) {
        fprintf(stderr, "illegal port number\n");
        return 1;
    }

    // create the socket
    int s=socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP);
    if(s==-1) {
        perror("socket");
        return 1;
    }

    // bind it to the specified port
    struct sockaddr_in addr;
    memset(&addr, 0, sizeof addr);
    addr.sin_family=AF_INET;
    addr.sin_port=htons(port);
    addr.sin_addr.s_addr=htonl(INADDR_ANY);
    if(bind(s, (struct sockaddr *)&addr, sizeof(addr))==-1) {
        perror("bind");
        return 1;
    }

    printf("sessiond " VERSION " started on port %u/UDP\n", port);
    daemon(0, 0);
    for(;;) // the main loop
        process_request(s);
}

// end of sessiond.cpp

==> sessiond-0.4.tar.gz: sessiond-0.4/sessiond.cpp <==
// sessiond - SSL session cache daemon, file sessiond.cpp
// Copyright (C) 2009 Michal Trojnara <Michal.Trojnara@mirt.net>
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2 of the License, or (at your
// option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, see <http://www.gnu.org/licenses>.
//
// Linking sessiond statically or dynamically with other modules is making
// a combined work based on sessiond. Thus, the terms and conditions of
// the GNU General Public License cover the whole combination.

#include "log.h"
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <signal.h>
#include <sys/socket.h>
#include <netinet/in.h>

// logging is performed every 5 minutes
#define LOG_FREQ 300

void process_request(const int, const u_short, LOG &); // defined in comm.cpp
static void handler(int);
static u_short port;
static int s;

int main(int argc, char *argv[]) {
    if(argc<2)
        port=54321;
    else
        port=atoi(argv[1]);
    if(!port) {
        fprintf(stderr, "illegal port number\n");
        return 1;
    }

    // create the socket
    s=socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP);
    if(s==-1) {
        perror("socket");
        return 1;
    }

    // bind it to the specified port
    struct sockaddr_in addr;
    memset(&addr, 0, sizeof addr);
    addr.sin_family=AF_INET;
    addr.sin_port=htons(port);
    addr.sin_addr.s_addr=htonl(INADDR_ANY);
    if(bind(s, (struct sockaddr *)&addr, sizeof(addr))==-1) {
        perror("bind");
        return 1;
    }

    printf("sessiond " VERSION " started on port %u/UDP\n", port);
    daemon(0, 0);
    LOG log;
    log.msg(LOG_NOTICE, "sessiond version " VERSION " started");
    alarm(LOG_FREQ);
    signal(SIGUSR1, handler);
    signal(SIGALRM, handler);
    for(;;) // the main loop
        process_request(s, port, log);
}

static void handler(int sig) { // send an empty UDP packet
    // only signal-safe functions are allowed in the signal handler
    alarm(LOG_FREQ);
    struct sockaddr_in addr;
    memset(&addr, 0, sizeof addr);
    addr.sin_family=AF_INET;
    addr.sin_port=htons(port);
    addr.sin_addr.s_addr=htonl(INADDR_LOOPBACK);
    sendto(s, "", 0, 0, (struct sockaddr *)&addr, sizeof addr);
}

// end of sessiond.cpp
